module Opennorth
  class Represent
    POSTAL_CODES_PATH = "/postcodes".freeze

    class Real
      def get_postal_code(postal_code)
        response = request(path: postal_code_path(postal_code),
               method: :get)

        response.body = JSON::parse(response.body)
        response
      end

      private
      def postal_code_path(postal_code)
        POSTAL_CODES_PATH + "/" + postal_code + "/"
      end
    end

    class Mock
      def get_postal_code(postal_code)
        Excon::Response.new.tap do |response|
          response.status = 200
          response.body = JSON::parse(data)
        end
      end

      private
      def data
        File.open(__FILE__).read.split(/^__END__/,2).last
      end
    end
  end
end
__END__

{"province": "BC", "city": "Vancouver", "boundaries_centroid": [{"url": "/boundaries/federal-electoral-districts/59029/", "boundary_set_name": "Federal electoral district", "external_id": "59029", "name": "Vancouver Centre", "related": {"boundary_set_url": "/boundary-sets/federal-electoral-districts/"}}, {"url": "/boundaries/census-divisions/5915/", "boundary_set_name": "Census division", "external_id": "5915", "name": "Greater Vancouver", "related": {"boundary_set_url": "/boundary-sets/census-divisions/"}}, {"url": "/boundaries/census-subdivisions/5915022/", "boundary_set_name": "Census subdivision", "external_id": "5915022", "name": "Vancouver", "related": {"boundary_set_url": "/boundary-sets/census-subdivisions/"}}, {"url": "/boundaries/british-columbia-electoral-districts/vancouver-fairview/", "boundary_set_name": "British Columbia electoral district", "external_id": "VFA", "name": "Vancouver-Fairview", "related": {"boundary_set_url": "/boundary-sets/british-columbia-electoral-districts/"}}], "code": "V6H2V4", "centroid": {"type": "Point", "coordinates": [-123.135993431, 49.26297987]}, "representatives_centroid": [{"first_name": "George", "last_name": "Affleck", "name": "George Affleck", "elected_office": "Councillor", "url": "http://vancouver.ca/your-government/george-affleck.aspx", "gender": "", "extra": {}, "related": {"boundary_url": "/boundaries/census-subdivisions/5915022/", "representative_set_url": "/representative-sets/vancouver-city-council/"}, "source_url": "http://vancouver.ca/your-government/george-affleck.aspx", "offices": [], "representative_set_name": "Vancouver City Council", "party_name": "", "district_name": "", "email": "clraffleck@vancouver.ca", "personal_url": "", "photo_url": "http://vancouver.ca/images/cov/feature/councillor-2012-affleck.jpg"}, {"first_name": "Elizabeth", "last_name": "Ball", "name": "Elizabeth Ball", "elected_office": "Councillor", "url": "http://vancouver.ca/your-government/elizabeth-ball.aspx", "gender": "", "extra": {}, "related": {"boundary_url": "/boundaries/census-subdivisions/5915022/", "representative_set_url": "/representative-sets/vancouver-city-council/"}, "source_url": "http://vancouver.ca/your-government/elizabeth-ball.aspx", "offices": [], "representative_set_name": "Vancouver City Council", "party_name": "", "district_name": "", "email": "clrball@vancouver.ca", "personal_url": "", "photo_url": "http://vancouver.ca/images/cov/feature/councillor-2012-ball.jpg"}, {"first_name": "Adriane", "last_name": "Carr", "name": "Adriane Carr", "elected_office": "Councillor", "url": "http://vancouver.ca/your-government/adriane-carr.aspx", "gender": "", "extra": {}, "related": {"boundary_url": "/boundaries/census-subdivisions/5915022/", "representative_set_url": "/representative-sets/vancouver-city-council/"}, "source_url": "http://vancouver.ca/your-government/adriane-carr.aspx", "offices": [], "representative_set_name": "Vancouver City Council", "party_name": "", "district_name": "", "email": "clrcarr@vancouver.ca", "personal_url": "", "photo_url": "http://vancouver.ca/images/cov/feature/councillor-2012-carr.jpg"}, {"first_name": "Heather", "last_name": "Deal", "name": "Heather Deal", "elected_office": "Councillor", "url": "http://vancouver.ca/your-government/heather-deal.aspx", "gender": "", "extra": {}, "related": {"boundary_url": "/boundaries/census-subdivisions/5915022/", "representative_set_url": "/representative-sets/vancouver-city-council/"}, "source_url": "http://vancouver.ca/your-government/heather-deal.aspx", "offices": [], "representative_set_name": "Vancouver City Council", "party_name": "", "district_name": "", "email": "clrdeal@vancouver.ca", "personal_url": "", "photo_url": "http://vancouver.ca/images/cov/feature/councillor-2012-deal.jpg"}, {"first_name": "Kerry", "last_name": "Jang", "name": "Kerry Jang", "elected_office": "Councillor", "url": "http://vancouver.ca/your-government/kerry-jang.aspx", "gender": "", "extra": {}, "related": {"boundary_url": "/boundaries/census-subdivisions/5915022/", "representative_set_url": "/representative-sets/vancouver-city-council/"}, "source_url": "http://vancouver.ca/your-government/kerry-jang.aspx", "offices": [], "representative_set_name": "Vancouver City Council", "party_name": "", "district_name": "", "email": "clrjang@vancouver.ca", "personal_url": "", "photo_url": "http://vancouver.ca/images/cov/feature/councillor-2012-jang.jpg"}, {"first_name": "Raymond", "last_name": "Louie", "name": "Raymond Louie", "elected_office": "Councillor", "url": "http://vancouver.ca/your-government/raymond-louie.aspx", "gender": "", "extra": {}, "related": {"boundary_url": "/boundaries/census-subdivisions/5915022/", "representative_set_url": "/representative-sets/vancouver-city-council/"}, "source_url": "http://vancouver.ca/your-government/raymond-louie.aspx", "offices": [], "representative_set_name": "Vancouver City Council", "party_name": "", "district_name": "", "email": "clrlouie@vancouver.ca", "personal_url": "", "photo_url": "http://vancouver.ca/images/cov/feature/councillor-2012-louie.jpg"}, {"first_name": "Geoff", "last_name": "Meggs", "name": "Geoff Meggs", "elected_office": "Councillor", "url": "http://vancouver.ca/your-government/geoff-meggs.aspx", "gender": "", "extra": {}, "related": {"boundary_url": "/boundaries/census-subdivisions/5915022/", "representative_set_url": "/representative-sets/vancouver-city-council/"}, "source_url": "http://vancouver.ca/your-government/geoff-meggs.aspx", "offices": [], "representative_set_name": "Vancouver City Council", "party_name": "", "district_name": "", "email": "clrmeggs@vancouver.ca", "personal_url": "", "photo_url": "http://vancouver.ca/images/cov/feature/councillor-2012-meggs.jpg"}, {"first_name": "Andrea", "last_name": "Reimer", "name": "Andrea Reimer", "elected_office": "Councillor", "url": "http://vancouver.ca/your-government/andrea-reimer.aspx", "gender": "", "extra": {}, "related": {"boundary_url": "/boundaries/census-subdivisions/5915022/", "representative_set_url": "/representative-sets/vancouver-city-council/"}, "source_url": "http://vancouver.ca/your-government/andrea-reimer.aspx", "offices": [], "representative_set_name": "Vancouver City Council", "party_name": "", "district_name": "", "email": "clrreimer@vancouver.ca", "personal_url": "", "photo_url": "http://vancouver.ca/images/cov/feature/councillor-2012-reimer.jpg"}, {"first_name": "Tim", "last_name": "Stevenson", "name": "Tim Stevenson", "elected_office": "Councillor", "url": "http://vancouver.ca/your-government/tim-stevenson.aspx", "gender": "", "extra": {}, "related": {"boundary_url": "/boundaries/census-subdivisions/5915022/", "representative_set_url": "/representative-sets/vancouver-city-council/"}, "source_url": "http://vancouver.ca/your-government/tim-stevenson.aspx", "offices": [], "representative_set_name": "Vancouver City Council", "party_name": "", "district_name": "", "email": "clrstevenson@vancouver.ca", "personal_url": "", "photo_url": "http://vancouver.ca/images/cov/feature/councillor-2012-stevenson.jpg"}, {"first_name": "Tony", "last_name": "Tang", "name": "Tony Tang", "elected_office": "Councillor", "url": "http://vancouver.ca/your-government/tony-tang.aspx", "gender": "", "extra": {}, "related": {"boundary_url": "/boundaries/census-subdivisions/5915022/", "representative_set_url": "/representative-sets/vancouver-city-council/"}, "source_url": "http://vancouver.ca/your-government/tony-tang.aspx", "offices": [], "representative_set_name": "Vancouver City Council", "party_name": "", "district_name": "", "email": "clrtang@vancouver.ca", "personal_url": "", "photo_url": "http://vancouver.ca/images/cov/feature/councillor-2012-tang.jpg"}, {"first_name": "Gregor", "last_name": "Robertson", "name": "Gregor Robertson", "elected_office": "Mayor", "url": "http://vancouver.ca/your-government/mayor-gregor-robertson.aspx", "gender": "", "extra": {}, "related": {"boundary_url": "/boundaries/census-subdivisions/5915022/", "representative_set_url": "/representative-sets/vancouver-city-council/"}, "source_url": "http://vancouver.ca/your-government/mayor-gregor-robertson.aspx", "offices": [], "representative_set_name": "Vancouver City Council", "party_name": "", "district_name": "", "email": "gregor.robertson@vancouver.ca", "personal_url": "", "photo_url": "http://vancouver.ca/images/cov/feature/mayor-2012-robertson.PNG"}, {"first_name": "George", "last_name": "Heyman", "name": "George Heyman", "elected_office": "MLA", "url": "http://www.leg.bc.ca/mla/40thparl/heyman-George.htm", "gender": "", "extra": {}, "related": {"boundary_url": "/boundaries/british-columbia-electoral-districts/vancouver-fairview/", "representative_set_url": "/representative-sets/bc-legislature/"}, "source_url": "http://www.leg.bc.ca/mla/3-1-6.htm", "offices": [{"tel": "1-250-387-3655", "fax": "1-250-387-4680", "postal": "Room 201\nParliament Buildings\nVictoria BC  V8V 1X4", "type": "legislature"}, {"tel": "1-604-775-2453", "fax": "1-604-660-6821", "postal": "642 West Broadway\nVancouver BC  V5Z 1G1", "type": "constituency"}], "representative_set_name": "Legislative Assembly of British Columbia", "party_name": "New Democratic Party of BC", "district_name": "Vancouver-Fairview", "email": "george.heyman.mla@leg.bc.ca", "personal_url": "", "photo_url": "http://www.leg.bc.ca/mla/40thparl/images/members_lrg/heyman-George.jpg"}, {"first_name": "Hedy", "last_name": "Fry", "name": "Hedy Fry", "elected_office": "MP", "url": "http://www.parl.gc.ca/MembersOfParliament/ProfileMP.aspx?Key=170551&Language=E", "gender": "", "extra": {"honorific_prefix": "Hon.", "preferred_language": "English"}, "related": {"boundary_url": "/boundaries/federal-electoral-districts/59029/", "representative_set_url": "/representative-sets/house-of-commons/"}, "source_url": "http://www.parl.gc.ca/MembersOfParliament/MainMPsCompleteList.aspx?TimePeriod=Current&Language=E", "offices": [{"type": "legislature", "fax": "1-613-995-0056", "postal": "House of Commons\nOttawa ON  K1A 0A6", "tel": "1-613-992-3213"}, {"type": "constituency", "fax": "1-604-666-0114", "postal": "1030 Denman St, Suite 106\nVancouver BC  V6G 2M6", "tel": "1-604-666-0135"}], "representative_set_name": "House of Commons", "party_name": "Liberal", "district_name": "Vancouver Centre", "email": "hedy.fry@parl.gc.ca", "personal_url": "http://www.hedyfry.com/", "photo_url": "http://www.parl.gc.ca/MembersOfParliament/Images/OfficialMPPhotos/41/FryHedy__Lib.jpg"}], "boundaries_concordance": []}
